##  FAQs
### How do I log in or register on SAP Learning?
For detailed information, refer to [Registration and login FAQs![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Flearning.sap.com%2Fhelpcenter%2Fgeneral%2Fregistration-login "https://learning.sap.com/helpcenter/general/registration-login").
### How do I get an SAP Universal ID or S-user ID?
For detailed information, refer to [SAP Universal ID![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.sap.com%2Faccount%2Funiversal-id.html?locale=en-US&state=PRODUCTION&version=CLOUD "https://www.sap.com/account/universal-id.html").
### How long are certifications valid?
  * SAP LeanIX Academy: Certifications expire 24 months after completion. After we sunset this platform, they will no longer be available. Ensure you download your certifications. To learn how, see [Download Your Course History and Certificates from SAP LeanIX Academy](https://help.sap.com/docs/leanix/ea/migration-of-sap-leanix-academy-courses-to-sap-learning?locale=en-US&state=PRODUCTION&version=CLOUD#loio3a975e8e24ca43888e9b09a637e60696__download-course-history-certificates).
  * SAP Learning: Certifications for SAP LeanIX on SAP Learning require a paid subscription. They’re valid for 12 months. To keep your certifications valid, you need to complete mandatory yearly assessments. To learn more about this process, see [Stay certified![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Flearning.sap.com%2Fcertification-transformation "https://learning.sap.com/certification-transformation"). As of January 2026, SAP certifications use a scenario-based assessment format similar to an instructor-led exam. To learn more, see [SAP Certification reimagined![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Flearning.sap.com%2Fget-certified%2Freimagining-certification "https://learning.sap.com/get-certified/reimagining-certification").


### What are the different subscription and pricing models on SAP Learning?
  * Free: As part of our customer-first approach, we offer most SAP LeanIX courses for free on SAP Learning. These courses are marked with a "Free" tag and are available publicly at no cost.
  * Enterprise Support: Courses marked with an "Enterprise Support" tag are available for free to SAP LeanIX customers. All customers with a cloud subscription have access to the Enterprise Support package.
  * SAP Learning Hub subscription: For additional learning, such as live sessions, instructor-led bootcamps, certifications, or further exclusive content, SAP Learning offers a yearly subscription. For details, visit the [SAP Learning Hub website![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.sap.com%2Ftraining-certification%2Flearning-hub.html?locale=en-US&state=PRODUCTION&version=CLOUD "https://www.sap.com/training-certification/learning-hub.html").
  * Certification attempts: For individual certification attempts, learners can also purchase one-time attempts or bundles of attempts. For details, visit [Validate your expertise with SAP Certification![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Ftraining.sap.com%2Fcontent%2Fpurchase-certification-attempts "https://training.sap.com/content/purchase-certification-attempts").


YesNo
Send
